@@ -1,14 +1,14 @@
 package Sort::Sub::pod_section_ala_perlancar;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-22'; # DATE
-our $DIST = 'Sort-SubBundle-PERLANCAR'; # DIST
-our $VERSION = '0.091'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-10-17'; # DATE
+our $DIST = 'Sort-SubBundle-PERLANCAR'; # DIST
+our $VERSION = '0.092'; # VERSION
+
 our $SORT_SPEC = [
     # ORIGINAL XXX are for forked modules, where the ORIGINAL XXX sections are
     # the sections from the original (forked) module, and the XXX sections are
@@ -117,6 +117,7 @@ our $SORT_SPEC = [
     'CONTRIBUTING',
 
     'COPYRIGHT AND LICENSE', 'ORIGINAL COPYRIGHT AND LICENSE',
+    'COPYRIGHT & LICENSE', 'ORIGINAL COPYRIGHT & LICENSE',
     'COPYRIGHT', 'ORIGINAL COPYRIGHT',
     'LICENSE', 'ORIGINAL LICENSE',
 
@@ -160,7 +161,7 @@ Sort::Sub::pod_section_ala_perlancar - Sort POD sections (headings) PERLANCAR-st
 
 =head1 VERSION
 
-This document describes version 0.091 of Sort::Sub::pod_section_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-08-22.
+This document describes version 0.092 of Sort::Sub::pod_section_ala_perlancar (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-10-17.
 
 =head1 SYNOPSIS
 
@@ -223,9 +224,26 @@ L<Sort::Sub>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2017, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
