@@ -1,9 +1,11 @@
 package Sort::SubBundle::PERLANCAR;
 
+use strict;
+
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-22'; # DATE
+our $DATE = '2021-10-17'; # DATE
 our $DIST = 'Sort-SubBundle-PERLANCAR'; # DIST
-our $VERSION = '0.091'; # VERSION
+our $VERSION = '0.092'; # VERSION
 
 1;
 # ABSTRACT: PERLANCAR's Sort::Sub subroutines
@@ -20,7 +22,7 @@ Sort::SubBundle::PERLANCAR - PERLANCAR's Sort::Sub subroutines
 
 =head1 VERSION
 
-This document describes version 0.091 of Sort::SubBundle::PERLANCAR (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-08-22.
+This document describes version 0.092 of Sort::SubBundle::PERLANCAR (from Perl distribution Sort-SubBundle-PERLANCAR), released on 2021-10-17.
 
 =head1 HOMEPAGE
 
@@ -34,9 +36,26 @@ Source repository is at L<https://github.com/perlancar/perl-Sort-SubBundle-PERLA
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2017, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
